@@ -1,5 +1,5 @@
 /* 
- *    Copyright 2015, 2016 (c) Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
+ *    Copyright 2015, 2016, 2017, 2018 (c) Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
  * 
  *    file: font_ops.c
  *    This file is part of fontopia.
@@ -21,6 +21,7 @@
 #include "defs.h"
 #include "view.h"
 #include "glyph.h"
+#include "font_ops.h"
 #include "modules/cp.h"
 #include "modules/raw.h"
 #include "modules/psf.h"
@@ -472,6 +473,25 @@ int create_empty_unitab(struct font_s *font)
   return 1;
 }
 
+int create_char_info(struct font_s* font)
+{
+    int sz = font->length*sizeof(struct char_info_s);
+    if(font->char_info) free(font->char_info);
+    struct char_info_s *char_info = (struct char_info_s *)malloc(sz);
+    if(!char_info) return 0;
+    memset(char_info, 0, sz);
+    font->char_info = (void *)char_info;
+    font->char_info_size = sz;
+    for(sz = 0; sz < font->length; sz++)
+    {
+        char_info[sz].encoding   = sz;
+        char_info[sz].dwidthX    = font->width;
+        char_info[sz].rBearing   = font->width;
+        char_info[sz].charAscent = font->height;
+    }
+    return 1;
+}
+
 struct font_s *new_font_file(struct font_s *font)
 {
   int res = check_font_saved(font, 1);
