@@ -1,5 +1,5 @@
 /* 
- *    Copyright 2015, 2016 (c) Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
+ *    Copyright 2015, 2016, 2017, 2018 (c) Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
  * 
  *    file: metrics.c
  *    This file is part of fontopia.
@@ -427,6 +427,7 @@ int show_font_metrics(struct font_s *font)
   
   int res = 0;
   int sel = 0;
+  int changed = 0;
   /* save these in case user cancelled */
   unsigned int old_height = font->height;
   unsigned int old_width = font->width;
@@ -593,6 +594,7 @@ skip:
 	    */
 	    font->charsize = font->height*((font->width+7)/8);
 	  }
+	  changed = 1;
 	  goto draw_win;
 	}
 	break;
@@ -603,8 +605,8 @@ skip:
     }
   }
   
-  /* user cancelled? */
-  if(res == 1)
+  /* user cancelled, or pressed OK but didn't make changes */
+  if(res == 1 || !changed)
   {
     /* restore old settings */
     font->height = old_height;
